@@ -123,9 +123,11 @@ sub BUILD {
 sub call {
     my ($self, $method, $param) = @_;
 
+    my $msgid = $self->_next_id->();
+
     my $request = [
         MP_TYPE_REQUEST,
-        $self->_next_id->(),
+        int($msgid), # should be IV
         $method,
         $param,
     ];
@@ -137,7 +139,8 @@ sub call {
         push @{ $self->_request_pool }, $request;
     }
 
-    $self->_callbacks->{ $request->[MP_REQ_MSGID] } = AnyEvent->condvar;
+    # $msgid is stringified, but $request->{MP_RES_MSGID] is still IV
+    $self->_callbacks->{ $msgid } = AnyEvent->condvar;
 }
 
 sub _handle_response {
@@ -172,15 +175,15 @@ AnyEvent::MPRPC::Client - Simple TCP-based MessagePack RPC client
 =head1 SYNOPSIS
 
     use AnyEvent::MPRPC::Client;
-    
+
     my $client = AnyEvent::MPRPC::Client->new(
         host => '127.0.0.1',
         port => 4423,
     );
-    
+
     # blocking interface
     my $res = $client->call( echo => 'foo bar' )->recv; # => 'foo bar';
-    
+
     # non-blocking interface
     $client->call( echo => 'foo bar' )->cb(sub {
         my $res = $_[0]->recv;  # => 'foo bar';
@@ -286,7 +289,7 @@ If server returns an error, C<<$cv->recv>> causes croak by using C<<$cv->croak>>
 
     my $res;
     eval { $res = $cv->recv };
-    
+
     if (my $error = $@) {
         # ...
     }
