@@ -23,6 +23,11 @@ has port => (
     required => 1,
 );
 
+has server => (
+    is => 'rw',
+    isa => 'Object',
+);
+
 has on_error => (
     is      => 'rw',
     isa     => 'CodeRef',
@@ -68,7 +73,7 @@ no Any::Moose;
 sub BUILD {
     my $self = shift;
 
-    tcp_server $self->address, $self->port, sub {
+    my $server = tcp_server $self->address, $self->port, sub {
         my ($fh, $host, $port) = @_;
         my $indicator = "$host:$port";
 
@@ -95,6 +100,7 @@ sub BUILD {
 
         $self->_handlers->[ fileno($fh) ] = $handle;
     };
+    $self->server($server);
     weaken $self;
 
     $self;
